@@ -43,7 +43,7 @@ bool Document_XML::load_after(int& failure_code)
   if(!bTest)
     return false; //Failed.
 
-#ifdef LIBXMLPP_EXCEPTIONS_ENABLED
+#ifdef LIBXMLCPP_EXCEPTIONS_ENABLED
   try
 #endif
   {
@@ -59,7 +59,7 @@ bool Document_XML::load_after(int& failure_code)
 
     return true; //Success.
   }
-#ifdef LIBXMLPP_EXCEPTIONS_ENABLED
+#ifdef LIBXMLCPP_EXCEPTIONS_ENABLED
   catch(const std::exception& ex)
   {
     std::cerr << "XML Parser error: \n" << ex.what() << std::endl;
@@ -91,7 +91,7 @@ bool Document_XML::save_before()
 //TODO: Why is this parameter here if it is not used?
 bool Document_XML::set_xml(const Glib::ustring& /* strXML */)
 { 
-#ifdef LIBXMLPP_EXCEPTIONS_ENABLED
+#ifdef LIBXMLCPP_EXCEPTIONS_ENABLED
   try
 #endif
   {
@@ -105,7 +105,7 @@ bool Document_XML::set_xml(const Glib::ustring& /* strXML */)
 
     return true;	
   }
-#ifdef LIBXMLPP_EXCEPTIONS_ENABLED
+#ifdef LIBXMLCPP_EXCEPTIONS_ENABLED
   catch(const std::exception& ex)
   {
     std::cerr << "XML Parser error: \n" << ex.what() << std::endl;
@@ -125,7 +125,7 @@ Glib::ustring Document_XML::get_xml() const
 
 void Document_XML::Util_DOM_Write(Glib::ustring& refstrXML) const
 {
-#ifdef LIBXMLPP_EXCEPTIONS_ENABLED
+#ifdef LIBXMLCPP_EXCEPTIONS_ENABLED
   try
 #endif
   {
@@ -134,7 +134,7 @@ void Document_XML::Util_DOM_Write(Glib::ustring& refstrXML) const
     else
       refstrXML = m_pDOM_Document->write_to_string();
   }
-#ifdef LIBXMLPP_EXCEPTIONS_ENABLED
+#ifdef LIBXMLCPP_EXCEPTIONS_ENABLED
   catch(xmlpp::exception& ex)
   {
     std::cerr << "Document_XML::Util_DOM_Write(): exception caught: " << ex.what() << std::endl;
@@ -237,14 +237,24 @@ xmlpp::Element* Document_XML::get_node_document()
   if(!m_pDOM_Document)
     m_pDOM_Document = m_DOM_Parser.get_document();
   
+  //Make sure that it has the DTD declaration:
+  //TODO: Put this in a better place, where it's more guaranteed to always be set?
+  //TODO: Add API to specify the PUBLIC URI, if the document should write this:
+  //SYSTEM (local) DTDs do not seem very useful.
+  //- means non-registered, which is commonly used.
+  //m_pDOM_Document->set_internal_subset(m_strRootNodeName, "-//glom/" + m_strDTD_Name, m_strDTD_Name);
+
   xmlpp::Element* nodeRoot = m_pDOM_Document->get_root_node();
   if(!nodeRoot)
   {
     //Add it if it isn't there already:
-    return m_pDOM_Document->create_root_node(m_strRootNodeName, m_root_xmlns);
+    nodeRoot = m_pDOM_Document->create_root_node(m_strRootNodeName, m_root_xmlns);
   }
-  else
-    return nodeRoot;
+  
+  //Make sure that it has the root name name and xmlns:
+  nodeRoot->set_namespace_declaration(m_root_xmlns);
+
+  return nodeRoot;
 }
 
 void Document_XML::set_write_formatted(bool formatted)
