@@ -21,8 +21,6 @@
 #ifndef DIALOG_BUTTONSCRIPT_H
 #define DIALOG_BUTTONSCRIPT_H
 
-#ifndef GLOM_ENABLE_CLIENT_ONLY
-
 #include <gtkmm.h>
 #include <gtkmm/builder.h>
 #include <libglom/data_structure/layout/layoutitem_button.h>
@@ -47,11 +45,11 @@ public:
   void get_script (const sharedptr<LayoutItem_Button>& script) const;
 
 private:
-  void on_button_test();
+  void on_button_test_script();
 
   Gtk::Entry* m_entry_title;
-  gtksourceview::SourceView* m_text_view;
-  Gtk::Button* m_button_test;
+  gtksourceview::SourceView* m_text_view_script;
+  Gtk::Button* m_button_test_script;
 
   sharedptr<LayoutItem_Button> m_script;
   Glib::ustring m_table_name;
@@ -59,5 +57,4 @@ private:
 
 } //namespace Glom
 
-#endif // !GLOM_ENABLE_CLIENT_ONLY
 #endif //DIALOG_BUTTONSCRIPT_H
