@@ -27,6 +27,7 @@
 #include <libglom/python_embed/py_glom_record.h>
 #include <libglom/python_embed/py_glom_related.h>
 #include <libglom/python_embed/py_glom_relatedrecord.h>
+#include <libglom/python_embed/py_glom_ui.h>
 
 using namespace Glom;
 
@@ -38,6 +39,7 @@ BOOST_PYTHON_MODULE(glom_1_14)
     .add_property("related", &PyGlomRecord::get_related)
 
     .def("__getitem__", &PyGlomRecord::getitem)
+    .def("__setitem__", &PyGlomRecord::setitem)
     .def("__len__", &PyGlomRecord::len)
   ;
 
@@ -54,4 +56,12 @@ BOOST_PYTHON_MODULE(glom_1_14)
     .def("__getitem__", &PyGlomRelatedRecord::getitem)
     .def("__len__", &PyGlomRelatedRecord::len)
   ;
+
+  boost::python::class_<PyGlomUI>("UI")
+    .def("show_table_details", &PyGlomUI::show_table_details)
+    .def("show_table_list", &PyGlomUI::show_table_list)
+    .def("print_layout", &PyGlomUI::print_layout)
+    .def("print_report", &PyGlomUI::print_report)
+    .def("start_new_record", &PyGlomUI::start_new_record)
+  ;
 }
