@@ -18,19 +18,21 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include "buttonglom.h"
+#include <glom/utility_widgets/buttonglom.h>
 #include <gtkmm/messagedialog.h>
-#include "../application.h"
-#include "../libglom/glade_utils.h"
-#include "dialog_layoutitem_properties.h"
-#include "../layout_item_dialogs/dialog_buttonscript.h"
+#include <glom/application.h>
+#include <glom/glade_utils.h>
+#include <glom/utils_ui.h>
+#ifndef GLOM_ENABLE_CLIENT_ONLY
+#include <glom/mode_design/layout/layout_item_dialogs/dialog_buttonscript.h>
+#endif
 #include <glibmm/i18n.h>
 //#include <sstream> //For stringstream
 
 namespace Glom
 {
 
-ButtonGlom::ButtonGlom(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& /* refGlade */)
+ButtonGlom::ButtonGlom(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& /* builder */)
 : Gtk::Button(cobject)
 {
   init();
@@ -50,19 +52,20 @@ void ButtonGlom::init()
 
 }
 
-App_Glom* ButtonGlom::get_application()
+Application* ButtonGlom::get_application()
 {
   Gtk::Container* pWindow = get_toplevel();
   //TODO: This only works when the child widget is already in its parent.
 
-  return dynamic_cast<App_Glom*>(pWindow);
+  return dynamic_cast<Application*>(pWindow);
 }
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
 void ButtonGlom::on_menu_properties_activate()
 {
   try
   {
-    Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom_developer.glade"), "window_button_script");
+    Glib::RefPtr<Gtk::Builder> refXml = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom_developer.glade"), "window_button_script");
 
     Dialog_ButtonScript* dialog = 0;
     refXml->get_widget_derived("window_button_script", dialog);
@@ -83,7 +86,7 @@ void ButtonGlom::on_menu_properties_activate()
       delete dialog;
     }
   }
-  catch(const Gnome::Glade::XmlError& ex)
+  catch(const Gtk::BuilderError& ex)
   {
     std::cerr << ex.what() << std::endl;
   }
@@ -91,7 +94,7 @@ void ButtonGlom::on_menu_properties_activate()
 
 bool ButtonGlom::on_button_press_event(GdkEventButton *event)
 {
-  App_Glom* pApp = get_application();
+  Application* pApp = get_application();
   if(pApp && pApp->get_userlevel() == AppState::USERLEVEL_DEVELOPER)
   {
     GdkModifierType mods;
@@ -105,5 +108,6 @@ bool ButtonGlom::on_button_press_event(GdkEventButton *event)
   }
   return Gtk::Button::on_button_press_event(event);
 }
+#endif
 
 } //namespace Glom
