@@ -23,9 +23,7 @@
 
 #include "config.h" // For GLOM_ENABLE_CLIENT_ONLY
 
-#include <gtkmm.h>
-#include <libglom/data_structure/field.h>
-#include "comboglomchoicesbase.h"
+#include <glom/utility_widgets/combochoiceswithtreemodel.h>
 
 #ifdef GLOM_ENABLE_MAEMO
 #include <hildonmm/picker-button.h>
@@ -47,7 +45,7 @@ class ComboGlom
 #else
   public Hildon::PickerButton,
 #endif
-  public ComboGlomChoicesBase
+  public ComboChoicesWithTreeModel
 {
 public:
 
