@@ -20,7 +20,7 @@
 
 #include "flowtable_dnd.h"
 #include "../mode_data/flowtablewithfields.h"
-#include "egg/toolpalette/eggtoolpalette.h"
+#include <gtkmm/toolpalette.h>
 #include "placeholder-glom.h"
 #include "layouttoolbarbutton.h"
 #include "entryglom.h"
@@ -32,18 +32,17 @@ namespace Glom
 {
 
 const std::string MOVE_TARGET = "FlowTableMoveTarget";
-  
+
 FlowTableDnd::FlowTableDnd() :
   m_current_dnd_item(0),
   m_internal_drag(false)
 {
   std::list<Gtk::TargetEntry> drag_targets;
 
-  const GtkTargetEntry* target_entry = egg_tool_palette_get_drag_target_item();
-  Gtk::TargetEntry toolbar_target(*target_entry);
+  const Gtk::TargetEntry toolbar_target = Gtk::ToolPalette::get_drag_target_item();
   drag_targets.push_back(toolbar_target);
 
-  Gtk::TargetEntry move_target(MOVE_TARGET);
+  const Gtk::TargetEntry move_target(MOVE_TARGET);
   drag_targets.push_back(move_target);
 
   drag_dest_set(drag_targets);
@@ -51,7 +50,7 @@ FlowTableDnd::FlowTableDnd() :
 
 FlowTableDnd::~FlowTableDnd()
 {
-  
+
 }
 
 void FlowTableDnd::start_dnd(Gtk::Widget& child)
@@ -85,15 +84,14 @@ void FlowTableDnd::start_dnd(Gtk::Widget& child)
   child.signal_drag_data_get().connect(sigc::bind<Gtk::Widget*>(sigc::mem_fun(*this, &FlowTableDnd::on_child_drag_data_get), &child), false);
   child.signal_drag_data_delete().connect(sigc::bind<Gtk::Widget*>(sigc::mem_fun(*this, &FlowTableDnd::on_child_drag_data_delete), &child), false);
 
-  if(!(child.get_flags() & Gtk::NO_WINDOW))
-  { 
+  if(child.get_has_window())
+  {
     std::list<Gtk::TargetEntry> drag_targets;
-    const GtkTargetEntry* target_entry = egg_tool_palette_get_drag_target_item();
-    Gtk::TargetEntry toolbar_target(*target_entry);
-    Gtk::TargetEntry move_target(MOVE_TARGET);
+    const Gtk::TargetEntry toolbar_target = Gtk::ToolPalette::get_drag_target_item();
     drag_targets.push_back(toolbar_target);
+    const Gtk::TargetEntry move_target(MOVE_TARGET);
     drag_targets.push_back(move_target);
-    
+
     Glib::RefPtr<Gtk::TargetList> targets = child.drag_dest_get_target_list();
 
     // The widget has already a default drag destination - add more targets:
@@ -121,7 +119,7 @@ void FlowTableDnd::stop_dnd(Gtk::Widget& child)
   if(dynamic_cast<PlaceholderGlom*>(&child) ||
       dynamic_cast<FlowTableDnd*>(&child))
     return;
-  
+
   // Call this method recursively for all (real) children:
   Gtk::Container* container = dynamic_cast<Gtk::Container*>(&child);
   if(container)
@@ -144,9 +142,9 @@ bool FlowTableDnd::on_drag_motion(const Glib::RefPtr<Gdk::DragContext>& /* drag_
   // the widget position. We fix this here to match the widget position
   x += get_allocation().get_x();
   y += get_allocation().get_y();
-  
-  m_current_dnd_item = dnd_item_at_position(x, y);  
-  Gtk::Widget* above = dnd_datawidget_from_item(0);
+
+  m_current_dnd_item = dnd_item_at_position(x, y);
+  Gtk::Widget* above = dnd_datawidget_from_item(m_current_dnd_item);
 
   // above might be 0 here...
   on_dnd_add_placeholder(above);
@@ -181,17 +179,23 @@ void FlowTableDnd::on_dnd_remove_placeholder()
 
 void FlowTableDnd::on_drag_data_received(const Glib::RefPtr<Gdk::DragContext>& drag_context, int /* drag_x */, int /* drag_y */, const Gtk::SelectionData& selection_data, guint, guint /* time */)
 {
-  Gtk::Widget* palette = drag_get_source_widget(drag_context);
-  while(palette && !EGG_IS_TOOL_PALETTE(palette->gobj()))
-    palette = palette->get_parent();
-  
+  Gtk::Widget* palette_candidate = drag_get_source_widget(drag_context);
+  Gtk::ToolPalette* palette = dynamic_cast<Gtk::ToolPalette*>(palette_candidate);
+  while(palette_candidate && !palette) {
+    palette_candidate = palette_candidate->get_parent();
+    palette = dynamic_cast<Gtk::ToolPalette*>(palette_candidate);
+  }
+
   on_dnd_remove_placeholder();
-  Gtk::Widget* above = dnd_datawidget_from_item(0);
-  if(palette)
+  Gtk::Widget* above = dnd_datawidget_from_item(m_current_dnd_item);
+  if(palette) //If the item was dragged from the palette.
   {
-    GtkWidget* tool_item = egg_tool_palette_get_drag_item(EGG_TOOL_PALETTE(palette->gobj()), selection_data.gobj());
-    const int type = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(tool_item), "glom-type"));
-    on_dnd_add_layout_item_by_type(type, above);
+    Gtk::Widget* tool_item = palette->get_drag_item(selection_data);
+    if(tool_item)
+    {
+      const int type = GPOINTER_TO_INT(tool_item->get_data("glom-type"));
+      on_dnd_add_layout_item_by_type(type, above);
+    }
   }
   else
   {
@@ -201,7 +205,7 @@ void FlowTableDnd::on_drag_data_received(const Glib::RefPtr<Gdk::DragContext>& d
 
     Gtk::Widget* widget = static_cast<Gtk::Widget*>(*pdata); //The type that was set in on_child_drag_data_get().
 
-    //A dynamic cast (from Gtk::Widget) is necessary because of the virtual inheritance: 
+    //A dynamic cast (from Gtk::Widget) is necessary because of the virtual inheritance:
     LayoutWidgetBase* base = dynamic_cast<LayoutWidgetBase*>(widget);
     if(base)
     {
@@ -225,7 +229,6 @@ void FlowTableDnd::on_drag_data_received(const Glib::RefPtr<Gdk::DragContext>& d
         base->set_dnd_in_progress(false);
       }
     }
-
   }
 }
 
@@ -237,15 +240,15 @@ void FlowTableDnd::on_drag_leave(const Glib::RefPtr<Gdk::DragContext>& /* drag_c
 // Calculate the nearest FlowTableDndItem below the current drag position
 FlowTable::FlowTableItem*
 FlowTableDnd::dnd_item_at_position(int drag_x, int drag_y)
-{ 
+{
   int column_width = 0;
   get_column_height(0, m_children.size(), column_width);
   int column = 0;
 
   if(column_width != 0)
     column = drag_x / column_width;
-  
-  for(std::vector<FlowTableItem>::iterator cur_item = m_children.begin(); cur_item != m_children.end(); 
+
+  for(std::vector<FlowTableItem>::iterator cur_item = m_children.begin(); cur_item != m_children.end();
        ++cur_item)
   {
     Gdk::Rectangle rect = cur_item->m_first->get_allocation();
@@ -255,14 +258,14 @@ FlowTableDnd::dnd_item_at_position(int drag_x, int drag_y)
       rect.set_height(MAX(rect.get_height(), second_rect.get_height()));
       rect.set_width(rect.get_width() + get_column_padding() + second_rect.get_width());
     }
-    
+
     int cur_column = 0;
     if(column_width != 0)
       cur_column = rect.get_x() / column_width;
-    
+
     if(cur_column != column)
-      continue;  
-    
+      continue;
+
     // Allow dragging at the end
     if(cur_item == --m_children.end())
     {
@@ -272,11 +275,11 @@ FlowTableDnd::dnd_item_at_position(int drag_x, int drag_y)
         return 0;
       }
     }
-    
+
     if(drag_y < (rect.get_y() + rect.get_height()))
       return &(*cur_item);
   }
-  
+
   return 0;
 }
 
@@ -284,12 +287,8 @@ Gtk::Widget* FlowTableDnd::dnd_datawidget_from_item(FlowTable::FlowTableItem* it
 {
   // Test if we have a datawidget below which we want to add
   LayoutWidgetBase* above = 0;
-  FlowTableItem* used_item = 0;
-  if(item)
-    used_item = item;
-  else
-    used_item = m_current_dnd_item;
-  
+  FlowTableItem* used_item = item;
+
   if(used_item)
   {
     if(used_item->m_first)
@@ -308,11 +307,11 @@ Gtk::Widget* FlowTableDnd::dnd_datawidget_from_item(FlowTable::FlowTableItem* it
 
       // Special case for labels
       if(!above)
-      {       
+      {
         Gtk::Alignment* alignment = dynamic_cast <Gtk::Alignment*>(used_item->m_second);
         if(alignment)
           above = dynamic_cast<LayoutWidgetBase*>(alignment->get_child());
-      } 
+      }
     }
   }
 
@@ -327,7 +326,7 @@ FlowTable::FlowTableItem* FlowTableDnd::find_current_dnd_item(Gtk::Widget* child
       cur_child != m_children.end(); ++cur_child)
   {
     // The widget was added directly to the FlowTableDnd
-    if(cur_child->m_first == child || 
+    if(cur_child->m_first == child ||
        cur_child->m_second == child)
     {
       break;
@@ -363,7 +362,7 @@ FlowTable::FlowTableItem* FlowTableDnd::find_current_dnd_item(Gtk::Widget* child
     item = &(*cur_child);
   else
     item = 0;
-  
+
   // Allow dragging at-the-end
   if(cur_child == --m_children.end() && y > 0)
   {
@@ -374,7 +373,7 @@ FlowTable::FlowTableItem* FlowTableDnd::find_current_dnd_item(Gtk::Widget* child
       item = 0; // means end
     }
   }
-  
+
   return item;
 }
 
@@ -382,9 +381,9 @@ bool FlowTableDnd::on_child_drag_motion(const Glib::RefPtr<Gdk::DragContext>& /*
                                         Gtk::Widget* child)
 {
   m_current_dnd_item = find_current_dnd_item(child, x, y);
-  
-  Gtk::Widget* above = dnd_datawidget_from_item(0);
-  
+
+  Gtk::Widget* above = dnd_datawidget_from_item(m_current_dnd_item);
+
   // above might be 0 here...
   on_dnd_add_placeholder(above);
   return false;
@@ -395,15 +394,15 @@ void FlowTableDnd::on_child_drag_leave(const Glib::RefPtr<Gdk::DragContext>& /*
   dnd_remove_placeholder_idle();
 }
 
-void FlowTableDnd::on_child_drag_data_received(const Glib::RefPtr<Gdk::DragContext>& drag_context, int x, int y, 
+void FlowTableDnd::on_child_drag_data_received(const Glib::RefPtr<Gdk::DragContext>& drag_context, int x, int y,
                                             const Gtk::SelectionData& selection_data, guint info, guint time,
                                             Gtk::Widget* /* child */)
 {
   on_drag_data_received(drag_context, x, y, selection_data, info, time);
 }
 
-void FlowTableDnd::on_child_drag_data_get(const Glib::RefPtr<Gdk::DragContext>& /* drag_context */, 
-                                          Gtk::SelectionData& selection_data, guint, guint /* time */, 
+void FlowTableDnd::on_child_drag_data_get(const Glib::RefPtr<Gdk::DragContext>& /* drag_context */,
+                                          Gtk::SelectionData& selection_data, guint, guint /* time */,
                                           Gtk::Widget* child)
 {
   FlowTableItem* item = find_current_dnd_item(child);
@@ -413,7 +412,7 @@ void FlowTableDnd::on_child_drag_data_get(const Glib::RefPtr<Gdk::DragContext>&
   if(base)
     data = base;
 
-  selection_data.set("Gtk::Widget*", 8, (guint8*)&data, 
+  selection_data.set("Gtk::Widget*", 8, (guint8*)&data,
                       sizeof(gpointer*));
 }
 
@@ -466,7 +465,7 @@ void FlowTableDnd::on_child_drag_end(const Glib::RefPtr<Gdk::DragContext>& /* dr
     if(item->m_first)
       item->m_first->show();
     if(item->m_second)
-      item->m_second->show();  
+      item->m_second->show();
   }
   else if(!m_internal_drag)
   {
@@ -483,7 +482,7 @@ void FlowTableDnd::on_child_drag_end(const Glib::RefPtr<Gdk::DragContext>& /* dr
 void FlowTableDnd::on_child_drag_data_delete(const Glib::RefPtr<Gdk::DragContext>& /* drag_context */,
                                Gtk::Widget* /* child */)
 {
-  // Do nothing for now  
+  // Do nothing for now
 }
 
 void FlowTableDnd::set_design_mode(bool value)
@@ -500,7 +499,7 @@ void FlowTableDnd::set_design_mode(bool value)
 /* This is a hack. The problem is that when you move the mouse down to the last
  item, the item gets the "drag-motion" signal but in the same moment, the placeholder
  is removed and the mouse pointer is no longer over the widget. Thus, it gets
- a "drag-leave" signal and it's impossible to drop an item at the end. Doing 
+ a "drag-leave" signal and it's impossible to drop an item at the end. Doing
  the removal of the placeholder in an idle handler fixes it. */
 
 void FlowTableDnd::dnd_remove_placeholder_idle()
